@@ -1,17 +1,33 @@
 GENRE_CODE = {
     "AAAA": "act",
-    "AAAB": "musical",
-    "BBBA": "dance",
+    "BBBC": "various_dance",
+    "BBBE": "popular_dance",
     "CCCA": "classic",
-    "CCCB": "opera",
     "CCCC": "korean_classical",
-    "EEEA": "complex"
+    "CCCD": "popular_music",
+    "EEEA": "complex",
+    "EEEB": "magic",
+    "GGGA": "musical"
+}
+
+GENRE_CODE_RESERVATION = {
+    "AAAA": "act",
+    "GGGA": "musical",
+    "CCCA": "classic",
+    "CCCC": "korean_classical",
+    "CCCD": "popular_music",
+    "BBBC": "dance",
+    "BBBR": "popular_dance",
+    "EEEB": "magic",
+    "EEEA": "complex",
+    "KID": "children",
+    "OPEN": "openrun"
 }
 
 
 AREA_CODE = {
     "11": "seoul",
-    "26": "busan",
+    "26": "busan",  
     "27": "daegu",
     "28": "inchon",
     "29": "gwangju",
